Black Sunrise Utrecht, Netherlands April 16th 2005 20 players Emile Bosman Deck Name: Dip me in chocolate, and throw me to the lesbians. Deck concept stealer: Emile Bosman Crypt (12 cards, min=10, max=29, avg=4.92) ------------------------------------------ 2x Gabrin 8 ANI CHI dom for Ravnos:2 1x Natalia 7 ANI chi dom for Ravnos:2 1x Joaquina Amaya 6 ANI CHI FOR Ravnos:2 1x Vaclav Petalengro 6 ANI CHI for pot Ravnos:2 1x Ghivran Dalaal, The Dead God 5 FOR ani aus chi Ravnos:2 1x Khalil Ravana 5 CHI ani for pre Ravnos:2 1x Salbatore Bokkengro 4 CHI for pro Ravnos:2 1x Tsigane 3 aus chi Ravnos:2 1x Vedel Esbreno 3 chi for Ravnos:2 1x Sasha Miklos 2 chi Ravnos:2 1x Spleen, Georgio Gutterpunk 2 ani chi Ravnos:2 Library (82 cards) Master (31) 1x Anarch Troublemaker 1x Archon Investigation 2x Direct Intervention 4x Dreams of the Sphinx 1x Erciyes Fragments, The 1x Fear of Mekhet 1x Fortune Teller Shop 4x Parthenon, The 2x Path of Paradox, The 1x Pentex(TM) Subversion 2x Ravnos Carnival 3x Svadharma 6x Tribute to the Master 2x Week of Nightmares Action (17) 1x Arson 6x Sensory Deprivation 10x Tumnimos Equipment (2) 1x Shilmulo Tarot 1x Treasured Samadji Action Modifier (14) 9x Fata Morgana 5x Red Herring Action Modifier/Combat (11) 6x Mirror Image 5x Occlusion Reaction (5) 5x Wake with Evening's Freshness Event (2) 2x Anthelios, The Red Star